# viridis: a tree python library

[![Build Status](https://travis-ci.org/jni/viridis.svg?branch=master)](https://travis-ci.org/jni/viridis)
[![Coverage Status](https://coveralls.io/repos/jni/viridis/badge.svg?branch=py3k)](https://coveralls.io/r/jni/viridis?branch=py3k)

Viridis is a Python library for tree data and algorithms. It is named
after _Morelia viridis_, the green tree python. It is compatible with and tested
with 100% coverage on both Python 2.7 and Python 3.4.

It is based on the excellent NetworkX graph library.

Initially, viridis only implements ultrametric trees and associated functions.
